@@ -4,7 +4,7 @@ use serde_json;
 
 pub struct Config {
     _host: String,
-    _port: i32 
+    _port: u16
 }
 
 impl Config { 
@@ -15,14 +15,14 @@ impl Config {
         Ok(Config {_host: config_dto.host, _port: config_dto.port})
     }
 
-    pub fn host(&self) -> &String { &self._host }
+    pub fn host(&self) -> &str { &self._host }
 
-    pub fn port(&self) -> i32 { self._port }
+    pub fn port(&self) -> u16 { self._port }
 }
 
 #[derive(Serialize, Deserialize, Debug)]
 struct ConfigDto {
     host: String,
-    port: i32, 
+    port: u16, 
 }
 
